# pdata

A general-purpose Python library for data analysis and visualization. 

## Modules overview

 - `datagen`: generate simulated data from probability distributions
 - `dirstructure`: analyze a directory in a file system and construct Pandas dataframes with data extracted from file names and the directory structure
 - `distributions`: estimate parameters of probability distributions
 - `ml`: helper functionality for machine learning tasks based on Scikit-learn
 - `pdutils`: utilities for processing of data stored in Pandas dataframes
 - `theanoutils`: utilities for creation and manipulation of Theano/PyMC3 objects
 - `visualize`: data visualization using Matplotlib